// Load data from CSV URL
d3.csv(
  'https://gist.githubusercontent.com/Yashwanth0402/e97c111c9f158eeb602089ce5500570a/raw/b249671479cf542aca212cc2b39c48ebbe45f0fb/gistfile1.txt',
).then(function (data) {
  // Parse date and time
  const parseDate = d3.timeParse('%Y,%H:%M');

  // Convert data types
  data.forEach((d) => {
    d.date = parseDate(`${d.Year},${d.time}`);
    d.Vancouver = +d.Vancouver;
  });

  // Set up dimensions for the plot
  const margin = {
    top: 20,
    right: 30,
    bottom: 50,
    left: 50,
  };
  const width = 800 - margin.left - margin.right;
  const height = 400 - margin.top - margin.bottom;

  // Create SVG element
  const svg = d3
    .select('#line-chart')
    .append('svg')
    .attr('width', width + margin.left + margin.right)
    .attr('height', height + margin.top + margin.bottom)
    .append('g')
    .attr(
      'transform',
      `translate(${margin.left},${margin.top})`,
    );

  // Create scales
  const xScale = d3
    .scaleTime()
    .domain(d3.extent(data, (d) => d.date))
    .range([0, width]);

  const yScale = d3
    .scaleLinear()
    .domain([270, 310])
    .range([height, 0]);

  // Create line generator
  const line = d3
    .line()
    .x((d) => xScale(d.date))
    .y((d) => yScale(d.Vancouver));

  // Append path element for the line
  svg
    .append('path')
    .datum(data)
    .attr('class', 'line')
    .attr('d', line);

  // Create x-axis
  svg
    .append('g')
    .attr('class', 'x-axis')
    .attr('transform', `translate(0,${height})`)
    .call(d3.axisBottom(xScale));

  // Create y-axis
  svg
    .append('g')
    .attr('class', 'y-axis')
    .call(d3.axisLeft(yScale));

  // Add x-axis label
  svg
    .append('text')
    .attr('class', 'x-axis-label')
    .attr('x', width / 2)
    .attr('y', height + margin.top + 20)
    .style('text-anchor', 'middle')
    .text('Date');

  // Add y-axis label
  svg
    .append('text')
    .attr('class', 'y-axis-label')
    .attr('transform', 'rotate(-90)')
    .attr('x', -height / 2)
    .attr('y', -margin.left + 20)
    .style('text-anchor', 'middle')
    .text('Temperature (K)');
});
